﻿using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using LinkMobility.PaymentCore.Sdk.Model;
using Microsoft.Practices.EnterpriseLibrary.TransientFaultHandling;

namespace MobileInvoice_demo_code
{
	class Program
	{
		static void Main(string[] args)
		{
			var program = new Program();

			var task = program.RunAsync();
			task.Wait();
			Console.ReadLine();
		}

		public async Task RunAsync()
		{
			var partnerId = 0; 
			var sharedKey = "";

			var testEnvironmentUri = new Uri("http://localhost:54209/api"); //"https://test-pay-core.linkmobility.com");
			var preTransactions = new[]
			{
				new
				{
					PartnerId = partnerId,
					Currency = "NOK",
					CustomerNo = "1234",
					InvoiceNo = "998877",
					MobileNumber = "+4799307499",
					Name = "Name of some customer in Norway"
				},
				new
				{
					PartnerId = partnerId,
					Currency = "SEK",
					CustomerNo = "2345",
					InvoiceNo = "887766",
					MobileNumber = "+4799307499",
					Name = "Name of some customer in Sweden"
				},
			};


			using (var client = LinkMobility.PaymentCore.Sdk.ClientFactory.Create(partnerId, sharedKey, testEnvironmentUri, TimeSpan.FromHours(60), RetryPolicy.DefaultExponential))
			{
				foreach (var preTransaction in preTransactions)
				{
					var preTransactionRequest = new PreTransactionRequest
					{
						PartnerId = preTransaction.PartnerId,
						//ReferenceId = "123", //Has to be unique for each pre-transaction if set
						Description = $"Test transaction",
						SmsNotificationOriginator = $"Test_{preTransaction.Currency}",
						SmsNotificationText = $"This is a test transaction. " + "Press here to pay: {{paymentSelectionPageUrl}}",
						ViewTemplateName = null, //"Template1",
						Amount = 1.0M,
						Currency = preTransaction.Currency,
						//TransactionReconRef = //OCR/KID,
						Msisdn = preTransaction.MobileNumber,
						CustomProperties = new Dictionary<string, string>
							{
								{"Name", preTransaction.Name},
								{"CustomerNo", preTransaction.CustomerNo},
								{"InvoiceNo", preTransaction.InvoiceNo},
							},
						//SmsStatusCallbackUrl = "http://example.com?customerno={{customerno}}&invoiceno={{invoiceno}}&sent={{smsNotificationSent}}&delivered={{smsNotificationDelivered}}&preTransactionId={{preTransactionId}}",
						//StatusCallbackUrl = "http://example.com?customerno={{customerno}}&invoiceno={{invoiceno}}&status={{status}}&pretransactionId={{transactionId}}&amount={{amount}}&paymenttype={{paymentType}}",
						PaymentProviders = new[] { "Nets"/* Mcash, Dibs, SweGiro, NetsVipps */}
					};

					try
					{
						var preTransactionId = await client.CreatePreTransactionAsync(preTransactionRequest);
						Console.WriteLine($"PreTransaction '{preTransactionId}' created");
					}
					catch (AggregateException ex)
					{
						foreach (var iex in ex.InnerExceptions)
						{
							//Do some errorhandling here
							Console.WriteLine(iex.Message);
						}
					}
					catch (Exception ex)
					{
						//Do some errorhandling here
						Console.WriteLine(ex.Message);
					}
				}
			}
		}
	}
}
